InstanceClientHandler

Trait InstanceClientHandler 

pub trait InstanceClientHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn on_drawn( &mut self, request: Request<OnDrawn, ___T>, ) -> impl Future<Output = ()> + Send; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send { ... } }
A client handler for the Instance protocol.

See Instance for more details.

Required Methods

fn on_drawn( &mut self, request: Request<OnDrawn, ___T>, ) -> impl Future<Output = ()> + Send

Update the client with the latest drawing state. The server makes no guarantees about how often this event occurs - it could occur multiple times per board state, for example.

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___T> InstanceClientHandler<___T> for IgnoreEvents
where ___T: Transport,

Source

async fn on_drawn(&mut self, _: Request<OnDrawn, ___T>)

Source

async fn on_unknown_interaction(&mut self, _: u64)

Implementors