#[repr(C)]pub struct InstanceAddLineResponse {}Trait Implementations
Sourceimpl Clone for InstanceAddLineResponse
impl Clone for InstanceAddLineResponse
Sourcefn clone(&self) -> InstanceAddLineResponse
fn clone(&self) -> InstanceAddLineResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstanceAddLineResponse
impl Debug for InstanceAddLineResponse
Sourceimpl<'a, ___E> Encode<InstanceAddLineResponse, ___E> for &'a InstanceAddLineResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InstanceAddLineResponse, ___E> for &'a InstanceAddLineResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceAddLineResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceAddLineResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InstanceAddLineResponse, ___E> for InstanceAddLineResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InstanceAddLineResponse, ___E> for InstanceAddLineResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceAddLineResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceAddLineResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InstanceAddLineResponse>, ___E> for &'a InstanceAddLineResponse
impl<'a, ___E> EncodeOption<Box<'static, InstanceAddLineResponse>, ___E> for &'a InstanceAddLineResponse
Sourcefn encode_option(
this: Option<&'a InstanceAddLineResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InstanceAddLineResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InstanceAddLineResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InstanceAddLineResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, InstanceAddLineResponse>, ___E> for InstanceAddLineResponse
impl<___E> EncodeOption<Box<'static, InstanceAddLineResponse>, ___E> for InstanceAddLineResponse
Sourcefn encode_option(
this: Option<InstanceAddLineResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InstanceAddLineResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InstanceAddLineResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InstanceAddLineResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<InstanceAddLineResponse> for InstanceAddLineResponse
impl FromWire<InstanceAddLineResponse> for InstanceAddLineResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InstanceAddLineResponse, InstanceAddLineResponse>
const COPY_OPTIMIZATION: CopyOptimization<InstanceAddLineResponse, InstanceAddLineResponse>
Sourcefn from_wire(wire: InstanceAddLineResponse) -> InstanceAddLineResponse
fn from_wire(wire: InstanceAddLineResponse) -> InstanceAddLineResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<InstanceAddLineResponse> for InstanceAddLineResponse
impl FromWireRef<InstanceAddLineResponse> for InstanceAddLineResponse
Sourcefn from_wire_ref(wire: &InstanceAddLineResponse) -> InstanceAddLineResponse
fn from_wire_ref(wire: &InstanceAddLineResponse) -> InstanceAddLineResponse
Converts the given reference to this type.
Sourceimpl Hash for InstanceAddLineResponse
impl Hash for InstanceAddLineResponse
Sourceimpl Ord for InstanceAddLineResponse
impl Ord for InstanceAddLineResponse
Sourcefn cmp(&self, other: &InstanceAddLineResponse) -> Ordering
fn cmp(&self, other: &InstanceAddLineResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InstanceAddLineResponse
impl PartialEq for InstanceAddLineResponse
Sourceimpl PartialOrd for InstanceAddLineResponse
impl PartialOrd for InstanceAddLineResponse
impl Copy for InstanceAddLineResponse
impl Eq for InstanceAddLineResponse
impl StructuralPartialEq for InstanceAddLineResponse