#[repr(C)]pub struct BoundingBox {
pub top_left: Point,
pub bottom_right: Point,
}Expand description
The wire type corresponding to BoundingBox.
Fields
top_left: Pointbottom_right: PointTrait Implementations
Sourceimpl Clone for BoundingBox
impl Clone for BoundingBox
Sourcefn clone(&self) -> BoundingBox
fn clone(&self) -> BoundingBox
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for BoundingBox
impl Constrained for BoundingBox
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, BoundingBox>,
_: <BoundingBox as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, BoundingBox>, _: <BoundingBox as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for BoundingBox
impl Debug for BoundingBox
Sourceimpl<___D> Decode<___D> for BoundingBoxwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for BoundingBoxwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<BoundingBox, ___E> for &'a BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BoundingBox, ___E> for &'a BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BoundingBox>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BoundingBox>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BoundingBox, ___E> for BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BoundingBox, ___E> for BoundingBoxwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
const COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BoundingBox>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BoundingBox>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<BoundingBox, ___E> for BoundingBox<T0, T1>
impl<___E, T0, T1> Encode<BoundingBox, ___E> for BoundingBox<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BoundingBox>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BoundingBox>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<BoundingBox> for BoundingBox
impl FromWire<BoundingBox> for BoundingBox
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
const COPY_OPTIMIZATION: CopyOptimization<BoundingBox, BoundingBox>
Sourcefn from_wire(wire: BoundingBox) -> BoundingBox
fn from_wire(wire: BoundingBox) -> BoundingBox
Converts the given owned value to this type.
Sourceimpl FromWireRef<BoundingBox> for BoundingBox
impl FromWireRef<BoundingBox> for BoundingBox
Sourcefn from_wire_ref(wire: &BoundingBox) -> BoundingBox
fn from_wire_ref(wire: &BoundingBox) -> BoundingBox
Converts the given reference to this type.
Sourceimpl IntoNatural for BoundingBox
impl IntoNatural for BoundingBox
Sourcetype Natural = BoundingBox
type Natural = BoundingBox
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for BoundingBox
impl Wire for BoundingBox
Sourcetype Narrowed<'de> = BoundingBox
type Narrowed<'de> = BoundingBox
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<BoundingBox>)
fn zero_padding(out_: &mut MaybeUninit<BoundingBox>)
Writes zeroes to the padding for this type, if any.